# EIDA Consistency Report: `INGV`

- Seed: `692335`
- Time: `2025-09-22T14:01:10.695048+00:00`
- Epochs requested: `20`
- Candidates requested: `20`
- Candidates tested: `None`
- Station queries performed: `None`
- Duration/epoch: `600 s`
- Total checks run: `20`
- Consistent: `15`
- Inconsistent: `5`
- Score: **75.0 %**

## Inconsistency Breakdown
- Availability says YES, Dataselect says NO: `0`
- Availability says NO, Dataselect says YES: `5`

## Dataselect Response Types
- **NoTrace**: `6`
- **SingleTrace**: `14`

---

## Detailed Results
### `MN.BNI..HLZ`
- Window: `2012-08-08T07:43:57 → 2012-08-08T07:53:57`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `MN.BNI..LHN`
- Window: `2003-11-14T21:21:59 → 2003-11-14T21:31:59`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `IV.USI..LHZ`
- Window: `2008-03-02T23:26:29 → 2008-03-02T23:36:29`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `MN.BNI..HLE`
- Window: `2010-01-22T06:50:20 → 2010-01-22T07:00:20`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `MN.IDI..LHE`
- Window: `2024-04-20T08:12:29 → 2024-04-20T08:22:29`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `IV.TSM6.T0.LS3`
- Window: `2023-04-22T17:15:30 → 2023-04-22T17:25:30`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `IV.MTCE..LHZ`
- Window: `2025-01-14T16:15:12 → 2025-01-14T16:25:12`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `IV.ESLN..BHZ`
- Window: `2006-07-25T21:10:24 → 2006-07-25T21:20:24`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `MN.BNI..VHN`
- Window: `2002-05-05T20:22:17 → 2002-05-05T20:32:17`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `IV.MTCE..VHN`
- Window: `2015-02-26T17:36:09 → 2015-02-26T17:46:09`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `AC.PHP.00.HHZ`
- Window: `2023-07-21T14:24:05 → 2023-07-21T14:34:05`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `IV.USI..HHZ`
- Window: `2024-07-26T10:49:57 → 2024-07-26T10:59:57`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `IV.TSM6.T3.RCB`
- Window: `2025-05-21T13:01:04 → 2025-05-21T13:11:04`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `IV.MOCO..HNN`
- Window: `2021-01-01T01:16:32 → 2021-01-01T01:26:32`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `GU.REMY..HHE`
- Window: `2011-11-20T03:09:58 → 2011-11-20T03:19:58`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `7M.NR20..EHZ`
- Window: `2021-04-25T14:51:26 → 2021-04-25T15:01:26`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `ZO.PDN4..HNZ`
- Window: `2031-11-26T04:20:04 → 2031-11-26T04:30:04`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `MN.IDI..HHN`
- Window: `2005-03-10T17:54:10 → 2005-03-10T18:04:10`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `MN.BNI..LHZ`
- Window: `1989-06-24T07:43:33 → 1989-06-24T07:53:33`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `MN.BNI..BHZ`
- Window: `2001-08-22T17:20:29 → 2001-08-22T17:30:29`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`
